#ifndef _WINC_AREAFILE
#define _WINC_AREAFILE

#include <WXP/AreaDir.h>
#include <WXP/AreaNav.h>
#include <WXP/Date.h>
#include <WXP/DomainVal.h>
#include <WXP/File.h>
#include <WXP/Gvar.h>
#include <WXP/Image.h>
#include <WXP/String.h>
#include <WXP/Swap.h>

namespace WXP {
   class AreaFile {
      File file;
      int file_type;
      Swap swap;
      bool opened;
      AreaDir dir;
      char nav_type[5];
      AreaNav nav;
      Gvar gvar;
      int bshift;
      
      public:
      AreaFile();
      int init();
      int open( const char *filename );
      bool isOpen();
      int rewind();
      int close();
      unsigned int readWord();
      unsigned char readByte();
      int getSync();
      int calcDomain( DomainVal &dom );
      int getImageDate( Date &date );
      int getImageDate();
      int getComment( String &str ); 
      /** Gets the satellite identifier */
      inline int getSatId(){ return dir.satid; }; 
      /** Gets line correction factor */
      inline int getLineCor(){ return dir.lcor; }; 
      /** Gets element correction factor */
      inline int getElemCor(){ return dir.ecor; }; 
      /** Gets line resolution */
      inline int getLineRes(){ return dir.lres; }; 
      /** Gets element resolution */
      inline int getElemRes(){ return dir.eres; }; 
      /** Gets line size */
      inline int getLineSize(){ return dir.lsiz; }; 
      /** Gets element size */
      inline int getElemSize(){ return dir.esiz; }; 
      /** Gets number of bands */
      inline int getBands(){ return dir.bands; }; 
      /** Gets the filter map */
      inline int getFilterMap(){ return dir.filtmap; }; 
      /** Gets the image identifier */
      inline int getImageId(){ return dir.imageid; }; 
      /** Gets the navigation type */
      inline const char *getNavType(){ return nav_type; }; 

      int read( Image &image );
      int readHeader();
      int readHeader( Image &image );
      int readData( Image &image );
      int print();
      int printNav();
      int printGvar();
      
   };
}
#endif
