#ifndef _WINC_CALC
#define _WINC_CALC

#include <WXP/Const.h>
#include <WXP/LclData.h>
   
namespace WXP {
   class Calc {
      public:
      static float windSpd( float u, float v );
      static float windDir( float u, float v );
      static float windU( float dir, float spd );
      static float windV( float dir, float spd );
      static float vaporPres( float t );
      static float windChillTemp( float temp, float ws );
      static float windChillTemp2( float temp, float ws );
      static float windChill( float temp, float ws );
      static float heatIndex( float temp, float dewp );
      static float humiture( float temp, float dewp );
      static float tempHumIndex( float temp, float dewp );
      static float sfcPrAlt( float alt, float el );
      static float presAlt( float pres );
      static float mixRatio( float temp, float pr );
      static float specHum( float temp, float pr );
      static float dewTemp( float temp, float rh );
      static float potTemp( float temp, float pr );
      static float virtTemp( float temp, float dewp, float pr );
      static float virtPotTemp( float temp, float dewp, float pr );
      static float tempOnSatAd( float pot, float pr );
      static float tempOnDryAd( float pot, float pr );
      static float thetaeOnSatAd( float temp, float pr );
      static float tempVaporPres( float e );
      static float tempOnMixRat( float w, float pr );
      static float relHum( float t, float td );
      static float convTemp( float wbar, float pc, float pr );
      static float lclPres( float ts, float tds, float ps);
      static float lclTemp( float ts, float ps, float plcl);
      static int lcl( float ts, float tds, float ps, LclData &ldat );
      static LclData lcl( float ts, float tds, float ps);
      static float equivPotTemp( float temp, float dewp, float pr );
      static float wetBulb( float temp, float dewp, float pr );
      static float wetBulbPotTemp( float temp, float dewp, float pr );
      static float interpLinear( float x,float x1,float x2,float y1,float y2 );
      static float interpTemp( float t1, float t2, float p1, float p2, float pr);
      static float earthDist( float lat1, float lon1, float lat2, float lon2);
      static float earthAngle( float lat1, float lon1, float lat2, float lon2);
      static float dist( float x1, float y1, float x2, float y2);

      /** Minimum value of two values */
      static inline float Min( float x, float y ){ 
         return x < y ? x : y;} 
      /** Maximum value of two values */
      static inline float Max( float x, float y ){ 
         return x > y ? x : y;} 
   
      /** Add two values and check for missing */
      static inline float ADD( float x, float y ){ 
         return x != Const::MISS && y != Const::MISS ? x+y : Const::MISS;} 
      /** Difference two values and check for missing */
      static inline float DIF( float x, float y ){ 
         return x != Const::MISS && y != Const::MISS ? x-y : Const::MISS;}
      /** Multiply two values and check for missing */
      static inline float MUL( float x, float y ){ 
         return x != Const::MISS && y != Const::MISS ? x*y : Const::MISS;}
      /** Divide two values and check for missing */
      static inline float DIV( float x, float y ){ 
         return x != Const::MISS && y != Const::MISS ? x/y : Const::MISS;}
   };
}   
#endif
