#ifndef _WINC_CONTPLOT
#define _WINC_CONTPLOT

#include <WXP/ColorFill.h>
#include <WXP/Domain.h>
#include <WXP/Grid.h>
#include <WXP/GridBox.h>
#include <WXP/GridPoint.h>
#include <WXP/Plot.h>
#include <WXP/PlotAttr.h>
#include <WXP/Point.h>
#include <WXP/String.h>

namespace WXP {
   class ContPlot {
      int type;
      String color_table;
      String color_fill;
      String color_line;
      String color_label;
      float min, max;
      float grid_min, grid_max;
      float base;
      float intrvl;
      float level, plevel;
      int num_cont;
      float conlo, conhi;
      ColorFill fill;
      GridBox box, pbox;
      int skipx, skipy, skipval;
      int extrad;
      int dash;
      int fill_pat;
      float line_width;
      float scale;
      char tform[10];
      int bar;
      
      public:
      ContPlot();
      ContPlot( const char *params );
      int init();
      int setParam( const char *str );
      int setType( int rtype );
      int setType( const char *str );
      /** Returns the contour type */
      inline int getType(){ return type; };
      /** Returns whether the plot is a color fill */
      inline bool isTypeFill(){ return ( type == FILL || type == BOTH )? true: false; };
      int setInterval( float val );
      /** Returns the contour interval */
      inline float getInterval(){ return intrvl; };
      int setBase( float val );
      /** Returns the contour base value */
      inline float getBase(){ return base; };
      /** Returns the maximum value in the grid */
      inline float getMax(){ return max; };
      /** Returns the minimum value in the grid */
      inline float getMin(){ return min; };
      int setLabelParam( int skip, int rad );
      int setLabelSpace( int x, int y );
      int setFillStyle( int type );
      int setLineWidth( float width );
      int setTextFormat( const char *fm );
      int setColorTable( const char *str );
      int setColorFill( const char *str );
      int setColorLine( const char *str );
      int setColorLabel( const char *str );
      int setScaleFactor( float sc );
      int draw( Plot &plot, Grid &grid );
      int drawLabels( Plot &plot, Grid &grid );
      int drawFill( Plot &plot, Grid &grid );
      int drawBoxFill( Plot &plot );
      int drawLine( Plot &plot, Grid &grid );
      int drawBoxLine( Plot &plot );
      int drawValues( Plot &plot, Grid &grid );
      int drawLineLabels( Plot &plot, Grid &grid );
      int drawMaxMin( Plot &plot, Grid &grid );
      float getLevel( int ind );
      /** Returns the plot attributes for a specific color fill */
      inline PlotAttr getColorFill( int ind ){ return fill.get( ind ); };
#ifdef SPLINE
      int setLoc( int ind, int x, int y, GridPoint &gpt );
      int getLine( Grid &grid, Domain &domain, int ind, 
   	    int x, int y, float level, int &npts, Point *pts );
      int drawSpline( Plot &plot, Grid &grid );
#endif

      /** Contour types */
      enum ContType { 
	 NONE,  /**< No contour output */
	 VALUE, /**< Plot grid values */
	 LINE,  /**< Plot line contours */
	 FILL,  /**< Plot fill contours */
	 BOTH   /**< Plot both line and fill contours */
      };

      static int decodeType( const char *str );
   };
}
#endif
