#ifndef _WINC_CONVERT
#define _WINC_CONVERT

#include <WXP/Const.h>

namespace WXP {
   /** \class Convert Convert.h "../include/Convert.h"
    *  \brief This defines some simple conversion factors
    *
    *  \author Dan Vietor
    *  \ingroup Utility
    */
   class Convert {
      public:
      /*
         Define some simple unit conversion macros
      */
      /** Celsius to Fahrenheit conversion */
      static inline float CtoF( float t ){
         return t != Const::MISS ? t*9/5+32 : Const::MISS;}
      /** Kelvin to Fahrenheit conversion */
      static inline float KtoF( float t ){ 
         return t != Const::MISS ? (t-273.15)*9/5+32 : Const::MISS;} 
      /** Celsius to Kelvin conversion */
      static inline float CtoK( float t ){ 
         return t != Const::MISS ? t+273.15 : Const::MISS;} 
      /** Fahrenheit to Kelvin conversion */
      static inline float FtoK( float t ){ 
         return t != Const::MISS ? (t-32.)*5/9+273.15 : Const::MISS;} 
      /** Fahrenheit to Celsius conversion */
      static inline float FtoC( float t ){ 
         return t != Const::MISS ? (t-32.)*5/9 : Const::MISS;} 
      /** Kelvin to Celsius conversion */
      static inline float KtoC( float t ){ 
         return t != Const::MISS ? t-273.15 : Const::MISS;} 
      /** Inches Hg to millibars conversion */
      static inline float INtoMB( float p ){ 
         return p != Const::MISS ? p*33.85399 : Const::MISS;} 
      /** Millibars to inches Hg conversion */
      static inline float MBtoIN( float p ){ 
         return p != Const::MISS ? p*.0295386 : Const::MISS;} 
      /** Knots to meters per second conversion */
      static inline float KTtoMPS( float w ){ 
         return w != Const::MISS ? w*.5144 : Const::MISS;} 
      /** Meters per second to knots conversion */
      static inline float MPStoKT( float w ){ 
         return w != Const::MISS ? w*1.944 : Const::MISS;} 
      /** Knots to kilometers per hour conversion */
      static inline float KTtoKMH( float l ){ 
         return l != Const::MISS ? l*1.852 : Const::MISS;} 
      /** Kilometers per hour to knots conversion */
      static inline float KMHtoKT( float l ){ 
         return l != Const::MISS ? l*0.53996 : Const::MISS;} 
      /** Knots to miles per hour conversion */
      static inline float KTtoMPH( float l ){ 
         return l != Const::MISS ? l*1.1508 : Const::MISS;} 
      /** Miles per hour to knots conversion */
      static inline float MPHtoKT( float l ){ 
         return l != Const::MISS ? l*0.86897 : Const::MISS;} 
      /** Miles perl hour to meters per second conversion */
      static inline float MPHtoMPS( float l ){ 
         return l != Const::MISS ? l*0.4470 : Const::MISS;} 
      /** Meters per second to miles per hour conversion */
      static inline float MPStoMPH( float l ){ 
         return l != Const::MISS ? l*2.23694 : Const::MISS;} 
      /** Feet to meters conversion */
      static inline float FTtoM( float l ){ 
         return l != Const::MISS ? l*.3048 : Const::MISS;} 
      /** Meters to feet conversion */
      static inline float MtoFT( float l ){ 
         return l != Const::MISS ? l*3.2808 : Const::MISS;} 
      /** Meters to miles conversion */
      static inline float MtoMI( float l ){ 
         return l != Const::MISS ? l*6.2136E-4 : Const::MISS;} 
      /** Inches to millimeters conversion */
      static inline float INtoMM( float l ){ 
         return l != Const::MISS ? l*25.4 : Const::MISS;} 
      /** Millimeters to inches conversion */
      static inline float MMtoIN( float l ){ 
         return l != Const::MISS ? l*.03937 : Const::MISS;} 
      /** Inches to centimeters conversion */
      static inline float INtoCM( float l ){ 
         return l != Const::MISS ? l*2.54 : Const::MISS;} 
      /** Centimeters to inches conversion */
      static inline float CMtoIN( float l ){ 
         return l != Const::MISS ? l*.3937 : Const::MISS;} 
      /** Statute miles to kilometers conversion */
      static inline float SMtoKM( float l ){ 
         return l != Const::MISS ? l*1.60934 : Const::MISS;} 
      /** Kilometers to statute miles conversion */
      static inline float KMtoSM( float l ){ 
         return l != Const::MISS ? l*.62137 : Const::MISS;} 
      /** Statute miles to nautical miles conversion */
      static inline float SMtoNM( float l ){ 
         return l != Const::MISS ? l*.86897 : Const::MISS;} 
      /** Nautical miles to statute miles conversion */
      static inline float NMtoSM( float l ){ 
         return l != Const::MISS ? l*1.1508 : Const::MISS;} 
      /** Nautical miles to kilometers conversion */
      static inline float NMtoKM( float l ){ 
         return l != Const::MISS ? l*1.852 : Const::MISS;} 
      /** Kilometers to nautical miles conversion */
      static inline float KMtoNM( float l ){ 
         return l != Const::MISS ? l*.53996 : Const::MISS;} 
      /** Nautical miles to feet conversion */
      static inline float NMtoFT( float l ){ 
         return l != Const::MISS ? l*6076.22 : Const::MISS;} 

   };
}
#endif
