#ifndef _WINC_DATA
#define _WINC_DATA

#include <WXP/Date.h>
#include <WXP/Datum.h>
#include <WXP/EarthPoint.h>
#include <WXP/String.h>
#include <WXP/VarSpec.h>

namespace WXP {
   class Data {
      String dinfo;
      String datim;
      Date date;
      char source[20];
      // Field specifications
      char **info;  // String describing each field
      VarSpec *vs;  // Variable specification for each field
      int *type;    // Type of each field
      int fields;   // Number of fields

      char **id;    // Identifier for each point
      EarthPoint *ept; // Location of each point
      float **value;// Float values 
      char ***str; // String values
      int num;      // Number of data points
      int limit;    // Allocated limit

      int initClass();
      public:
      
      Data();
      Data( int rfields );
      ~Data();
      Data( const Data &data );
      Data operator=(const Data &data );
      static int copyInfo( Data &data1, const Data &data2 );
      static int copy( Data &data1, const Data &data2 );
      int copy( Data &data );

      int init();
      int clear();
      inline int getNum(){ return num; };
      int setSource( const char *str );
      inline const char *getSource(){ return source; };
      int setFields( int rfields );
      inline int getFields(){ return fields; };
      int setType( int fld, int rtype );
      int getType( int fld );
      int expand( int rlimit );
      int expand();
      int setDate( Date &rdate );
      inline int getDate( Date &rdate ){ rdate = date; return 1; };
      inline Date getDate(){ return date; };
      int setDatim( const char *rdatim );
      const char *getDatim();
      int setInfo( const char *rinfo );
      const char *getInfo();
      int setInfo( int ind, const char *rinfo );
      const char *getInfo( int ind );
      int searchInfo( const char *str );
      int setUnits( int ind, const char *unit );
      const char *getUnits( int ind );
      int setVarSpec( int fld, VarSpec &rvs );
      int getVarSpec( int fld, VarSpec &rvs );
      int getIndex( const char *rid );
      int setId( int ind, const char *rid );
      const char *getId( int ind );
      int setLoc( int ind, EarthPoint &rpt );
      int setLoc( int ind, float lat, float lon );
      int getLoc( int ind, EarthPoint &rpt );
      EarthPoint getLoc( int ind );
      int setValue( int ind, float rval );
      int setValue( int ind, int fld, float rval );
      int setString( int ind, const char *rstr );
      int setString( int ind, int fld, const char *rstr );
      int add( Data &data, int ind, int fld );
      int add( Data &data, int ind );
      int add( const char *rid, EarthPoint &rpt, float rval );
      int add( const char *rid, EarthPoint &rpt, float rval1, float rval2 );
      int add( Datum &datum );
      int addValue( EarthPoint &rpt, float val );
      float getValue( int ind );
      float getValue( int ind, int fld );
      const char *getString( int ind );
      const char *getString( int ind, int fld );
      int print();
      int printData(int ind);
      int printData();

      enum Type { 
	 NONE,
	 VALUE,
	 STRING
      };
   };
}
#endif
