#ifndef _WINC_DEVICE
#define _WINC_DEVICE

#include <WXP/Image.h>
#include <WXP/Listener.h>
#include <WXP/Point.h>
#include <WXP/Points.h>
#include <WXP/Rect.h>
#include <WXP/String.h>

namespace WXP {
   /** \class Device Device.h "../include/Device.h"
    *  \brief This virtual class defines methods for output to generic device
    *
    *  \author Dan Vietor
    *  \ingroup Device
    */
   
   class Device {
      public:
      static const int BASE = 0;
      static const int LINE = 1;
      static const int MARK = 2;
      static const int FILL = 3;
      static const int TEXT = 4;
   
      static const int LAST = -1;
      static const int CUR  = -2;
      static const int WIN  = -3;
      static const int ALL  = -4;
   
      static const int CURSOR_X    = 0;
      static const int CURSOR_PTR  = 1;
      static const int CURSOR_MOVE = 2;
      static const int CURSOR_LOOP = 3;
      static const int CURSOR_STOP = 4;
      static const int CURSOR_DRAW = 5;
      static const int CURSOR_RECT = 6;
      static const int CURSOR_PLUS = 6;
      static const int CURSOR_TEXT = 7;
      static const int CURSOR_WAIT = 8;

      static const int ALIGN_HLEFT   = 1;
      static const int ALIGN_HCENTER = 2;
      static const int ALIGN_HRIGHT  = 3;
   
      static const int ALIGN_VBOTTOM = 1;
      static const int ALIGN_VCENTER = 2;
      static const int ALIGN_VTOP    = 3;
   
      virtual ~Device() {}
      virtual int init() = 0;
      virtual int setParam( const char *str ) = 0;
      virtual int open() = 0;
      virtual int getDevice( String &str ) = 0;
      virtual int resize(float rwidth, float rheight) = 0;
      virtual int manage() = 0;
      virtual int unmanage() = 0;
      virtual int addCallback( const char *event, Listener *list, const void *data ) = 0;
      virtual int doCallback( const char *ev_str, const char *ev_data ) = 0;
      virtual void callback( const char *ev_str, const char *ev_data, const void *data ) = 0;
      virtual int close() = 0;
      virtual int update() = 0;
      virtual int clear() = 0;
      virtual int clearRect(Rect &rect) = 0;
      virtual int setTitle(const char *str) = 0;
      virtual int setIcon(bool val) = 0;
      virtual int setFixed(bool val) = 0;
      virtual int setInverse(bool val) = 0;
      virtual bool getInverse() = 0;
      virtual int setBackground(const char *str) = 0;
      virtual int setSize(float rwidth, float rheight) = 0;
      virtual int getSize(float &width, float &height) = 0;
      virtual float getWidth() = 0;
      virtual float getHeight() = 0;
      virtual int setOffset(float rx, float ry) = 0;
      virtual int getOffset(float &x, float &y) = 0;
      virtual int getCoords( Rect &rect ) = 0;
      virtual Rect getCoords() = 0;
      virtual int allocColor( float red, float grn, float blu ) = 0;
      virtual int setColor( int type, int ind ) = 0;
      virtual int setLineWidth( int type, float width ) = 0;
      virtual int setLineStyle( int type, int style ) = 0;
      virtual int setFillStyle( int type, int style ) = 0;
      virtual int drawLine( int type, float x1, float y1, float x2, float y2 ) = 0;
      virtual int drawLine( int type, Points &pts ) = 0;
      virtual int drawFill( int type, Points &pts ) = 0;
      virtual int setImageAlign( int h, int v ) = 0;
      virtual int drawImage( Image &image, float x, float y ) = 0;
      virtual int drawImage( Image &image, int bgcolor, float x, float y ) = 0;
      virtual int getImage( Image &image ) = 0;
      virtual int setFont( const char *name ) = 0;
      virtual int setTextAlign( int h, int v ) = 0;
      virtual int drawText( Point &pt, const char *str ) = 0;
      virtual Rect getClip() = 0;
      virtual int setClip( float x1, float y1, float x2, float y2 ) = 0;
      virtual int setClip( Rect rect ) = 0;
      virtual int setCursor( int type ) = 0;
      virtual int copyFrame( int dest, int src ) = 0;
      virtual int displayFrame( int ind ) = 0;
      virtual int clearFrame( int ind ) = 0;
      virtual int newFrame( int ind ) = 0;
      virtual int newFrame() = 0;
      virtual bool isLooping() = 0;
      virtual int getFrame() = 0;
      virtual int setFrame( int ind ) = 0;
      virtual int incFrame( int step ) = 0;
      virtual int deleteFrame( int ind ) = 0;
      virtual int getNumFrames() = 0;
      virtual int message( const char *str ) = 0;
      virtual int bell( int len ) = 0;
   };
}   
#endif
