#ifndef _WINC_DOMAINVAL
#define _WINC_DOMAINVAL

namespace WXP {
   struct DomainVal {
      int proj;                 /**< Grid projection */
      float plat;               /**< Projection latitude */
      float plon;               /**< Projection longitude */
      float param[5];           /**< Extra projection parameters */
      float clat;               /**< Central latitude of domain */
      float clon;               /**< Central longitude of domain */
      float dx;                 /**< Grid spacing in X */
      float dy;                 /**< Grid spacing in Y */
      int nx;                   /**< Number of grid points in X direction */
      int ny;                   /**< Number of grid points in Y direction */
      bool ellipse;             /**< Use ellipsoidal earth */
   
      DomainVal();
      int init();
      float getAspect();
      int print();
   
      static bool compare( DomainVal &dom1, DomainVal &dom2 );
      static bool compareProj( DomainVal dom1, DomainVal dom2 );

      static const int PSTEREO = 1;      /**< Polar stereographic */
      static const int LATLON  = 2;      /**< Latitude longitude */
      static const int MERC    = 3;      /**< Mercator */
      static const int LAMB    = 4;      /**< Lambert conformal */
      static const int ORTHO   = 5;      /**< Orthographic */
      static const int GNOM    = 6;      /**< Gnomic */
      static const int MOLL    = 7;      /**< Molleweide */
      static const int LAMBAZ  = 8;      /**< Lambert azithumal */
      static const int ALBERS  = 9;      /**< Albers equal area */
      static const int SAT    = 10;      /**< Satellite */
      static const int RADIAL = 11;      /**< Radar radial */
      static const int PIXEL  = 20;      /**< Pixel space */
      static const int XY     = 21;      /**< XY Cartesian */
      static const int XZ     = 22;      /**< XZ Cartesian */
      static const int XP     = 23;      /**< X-Pres Cartesian */
      static const int XLOGP  = 24;      /**< X-logP Cartesian */
      static const int POLAR  = 25;      /**< Polar coordinate */
      static const int CAT    = 26;      /**< Category plot */
      static const int SKEWT  = 40;      /**< SkewT thermodynamic diagram */
      static const int STUVE  = 41;      /**< Stuve thermodynamic diagram */
      static const int EMA    = 42;      /**< Emagram thermodynamic diagram */
      static const int TEPH   = 43;      /**< Tephigram thermodynamic diagram */
      static const int RTEPH  = 44;      /**< Rotated Tephigram thermodynamic diagram */
      static const int ZOOM   = 50;      /**< Specifies zoom parameters */
      static const int SIZE   = 51;      /**< Specifies size of grid/image only */
   };
}
#endif

