#ifndef _WINC_FRONTPLOT
#define _WINC_FRONTPLOT

#include <WXP/Date.h>
#include <WXP/Domain.h>
#include <WXP/Drawing.h>
#include <WXP/Filename.h>
#include <WXP/FrontData.h>
#include <WXP/Listener.h>
#include <WXP/Plot.h>
#include <WXP/Point.h>
#include <WXP/String.h>
#include <WXP/Timezone.h>

namespace WXP {
   class FrontPlot : public Drawing, public Listener {
      int pr_lab;           /* Pressure labels */
      float pr_rad;         /* Pressure labels */
      int barb;             /* Barbs */
      float scale;          /* Scale factor */
      int hour;             /* Forecast hour */
      int shadow;
      int map;
      int sync;
      String color;
      Filename filename;
      Timezone tz;

      public:
      FrontPlot();
      FrontPlot( const char *param );
      int init();
      int setParam( const char *str );
      int setFile();
      int setInput( const char *type );
      int setNameConv( const char *type );
      int setFilename();
      int setFilename( const char *str );
      int setFilename( Date &date );
      int setFilename( Date &date, const char *param );
      int getDate( Date &date );
      int getInitDate( Date &date );
      int getDateOffset();
      int getLoopType();
      int setForeTime( const char *fore );
      int getNumFrames();
      int getDomain( Domain &domain );
      int setColor( const char *str );
      /** Sets whether map is to be plotted */
      inline int setMap( bool val ){ map = val; return 1; };
      /** Returns whether object is to be time sync */
      inline int getSync(){ return sync; };
      int draw( Plot &plot );
      int draw( Plot &plot, FrontData &data );
      int drawTriangle( Plot &plot, Point &pt1, Point &pt2, int dir );
      int drawHalfCircle( Plot &plot, Point &pt1, Point &pt2, int dir );
      void callback( const char *ev_str, const char *ev_data, const void *data );
      int print();
   };
}
#endif
