#ifndef _WINC_GRAPH
#define _WINC_GRAPH

#include <WXP/Device.h>
#include <WXP/GFont.h>
#include <WXP/GTran.h>
#include <WXP/GraphAttr.h>
#include <WXP/Image.h>
#include <WXP/Listener.h>
#include <WXP/Point.h>
#include <WXP/Points.h>
#include <WXP/Rect.h>
#include <WXP/RGB.h>
#include <WXP/String.h>
#include <WXP/Symbol.h>

namespace WXP {
   class Graph : public Listener, public GraphAttr {
      bool opened;
      Device *window;
      static const int max_tran = 4;
      GTran tran[max_tran];
      int ctran;
      int font_type;
      char font_name[40];    // The WXP font name
      char font_spec[120];   // The device specific font specification
      GFont font;
      char symb_file[80];
      Symbol symbol;
      Points pts;
   
      int device;
      bool managed;
      bool fixed;
   
      int line_color;       /* Line color */
      float line_width;          /* Line width */
      int line_style;            /* Line style */
   
      int fill_color;       /* Fill color */
      int fill_style;            /* Fill style */
      /*
         Text attributes
      */
      int hfont;          // Use hardware font
      int text_color;       /* Text color */
      float text_width;          /* Text width */
      float text_height;         /* Text height */
      float text_expan;          /* Text expansion factor */
      float text_char_space;     /* Space factor between characters */
      float text_char_width;     /* Width of each character */
      int text_halign;           /* Horizontal text alignment */
      int text_valign;           /* Vertical text alignment */
      float text_upx, text_upy;  /* Text up vector */
      int text_box_color;
      bool text_box;
      int drop_color;
      int drop_shadow;
      int drop_width;
      int mark_type;             /* Marker type */
      float mark_size;           /* Marker size */
      float mark_width;          /* Marker width */
      int mark_color;            /* Marker color */

      int drawTextLine( float ox, float oy, const char *string );
      int initClass();
   public:
   
      Graph();
      Graph( const char *device, const char *param );
      ~Graph();
      int init();
      int setDevice( const char *device, const char *params );
      int getDevice( String &str );
      int open();
      int open( const char *dev, const char *params );
      bool isOpen();
      int close();
      int update();
      int manage();
      int unmanage();
      /** Returns true if window managed */
      inline bool isManaged(){ return managed; };
      void callback( const char *ev_str, const char *ev_data, const void *data );
      int doCallback( const char *ev_str, const char *ev_data );
      int addCallback( const char *ev, Listener *list, const void *data );
      int setFixed( bool val );
      int setSize( float width, float height );
      int setOffset( float rx, float ry );
      int setInverse( bool val );
      bool getInverse();
      int setBackground( const char *str );
      int setIcon( bool val );
      int setTitle( const char *str );
      int setTran( int num );
      int setViewportAspect( Rect &limit, float aspect, int halign, int valign );
      int setViewportAspect( Rect &limit, float aspect );
      int setViewport( int num, Rect &rect );
      int setViewport( Rect &rect );
      int getViewport( Rect &rect );
      Rect getViewport();
      int getDeviceViewport( Rect &rect );
      Rect getDeviceViewport();
      int getMaxViewport( Rect &rect );
      Rect getMaxViewport();
      int setWindow( int num, Rect &rect );
      int setWindow( Rect &rect );
      int getWindow( Rect &rect );
      Rect getWindow();
      int getTran();
      int activateTran();
      int activateTran( int val );
      int tranPlotView( float x1, float y1, float &x2, float &y2 );
      int tranPlotWindow( float x1, float y1, float &x2, float &y2 );
      int tranPlotWindow( Point &pt1, Point &pt2 );
      int tranWindow( int tran1, float x1, float y1, int tran2, float &x2, float &y2 );
      int tranWindow( int tran1, Point &pt1, int tran2, Point &pt2 );
      int clear();
      int clearRect( Rect &rect );
      int allocColor( float red, float grn, float blu );
      int allocColor( RGB &rgb );
      int drawLine( float x1, float y1, float x2, float y2 );
      int drawLine( Point &p1, Point &p2 );
      int drawLine( Points &data );
      int drawRect( float x1, float y1, float x2, float y2 );
      int drawRect( Rect &rect );
      int drawCircle( float x1, float y1, float rad );
      int drawCircle( Point &pt, float rad );
      int setLineColor( int index );
      int setLineWidth( float width );
      int setLineStyle( int style );
      int drawFill( Rect &rect );
      int drawFill( Points &data );
      int drawFillarea( Points &data );
      int setFillColor( int index );
      int setFillStyle( int index );
      int drawMarkLine( float x, float y, float size );
      int drawMark( float x, float y );
      int drawMark( Point pt );
      int setMarkColor( int index );
      int setMarkSize( float size );
      int setMarkType( int type );
      int setMarkWidth( float width );
      int drawText( float ox, float oy, const char *string );
      int drawText( Point pt, const char *string );
      int drawFormText( float x, float y, const char *format, ... );
      int drawFormText( Point pt, const char *format, ... );
      int setTextColor( int color );
      int setFontSpec();
      int setFont( const char *str );
      int setTextBoxColor( int index );
      int setDropColor( int index );
      int setDropShadow( int val );
      int getDropShadow();
      int setDropWidth( int val );
      int setTextExpansion( float expansion );
      int setTextWidth( float width );
      int setTextHeight( float height );
      int setTextDirection( float x, float y );
      int setTextAlign( int hor, int vert );
      int setTextCharWidth( float space );
      int setTextSpacing( float space );
      int setSymbol( const char *file );
      int drawSymbol( float ox, float oy, const char *string, float size );
      int drawSymbol( Point pt, const char *string, float size );
      int setImageAlign( int h, int v );
      int drawImage( Image &image, float x, float y );
      int drawImage( Image &image, int color, float x, float y );
      int getImage( Image &image );
      int setCursor( int type );
      bool isLooping();
      int getFrame();
      int setFrame( int ind );
      int newFrame();
      int deleteFrame(int ind);
      int getNumFrames();
      int bell();
      int message( const char *str, ... );
      int printTran();

      static const int DEVICE_NONE       = 0;
      static const int DEVICE_WINDOW     = 1;
      static const int DEVICE_POSTSCRIPT = 2;
      static const int DEVICE_HPGL       = 3;
      static const int DEVICE_METAFILE   = 4;
   };
}
#endif
