#ifndef _WINC_GRIDMATH
#define _WINC_GRIDMATH
   
#include <WXP/Domain.h>
#include <WXP/Grid.h>
#include <WXP/Grids.h>

namespace WXP {
   class GridMath {
      public:

      static int process( const char *func, Grid &ogrid, Grids &grids );
      static bool checkVar( Grid &grid, const char *var );
      static int setInfo( Grid &ogrid, const char *name, const char *units );
      static int units( Grid &grid, const char *units );
      static bool isDomainEqual( Grid &grd1, Grid &grd2 );
      static bool isDomainEqual( Grid &grd1, Domain &dom );
      static bool isProjEqual( Grid &grd1, Grid &grd2 );
      static bool isProjEqual( Grid &grd1, Domain &dom );
      static float maxSpd( Grid &ugrid, Grid &vgrid );
      static int remap( Grid &ogrid, Domain &domain, Grid &igrid );
      static int cutoff( Grid &ogrid, const char *cmd, float cutoff, 
	    float nval, Grid &igrid );
      static int resetMiss( Grid &grid, float nval );
      static int scale( Grid &ogrid, float scale );
      static int offset( Grid &ogrid, float off );
      static int interp( Grid &ogrid, Grid &grid1, float ival, Grid &grid2 );
      static int add( Grid &ogrid, Grid &igrid );
      static int add( Grid &ogrid, Grid &agrid, Grid &bgrid );
      static int add( Grid &ogrid, Grids &grids );
      static int avg( Grid &ogrid, Grids &grids );
      static int diff( Grid &ogrid, Grid &igrid );
      static int diff( Grid &ogrid, Grid &grida, Grid &gridb );
      static int mult( Grid &ogrid, Grid &grida, Grid &gridb );
      static int div( Grid &ogrid, Grid &grida, Grid &gridb );
      static int mod( Grid &ogrid, Grid &grida, Grid &gridb );
      static int max( Grid &ogrid, Grids &grids );
      static int min( Grid &ogrid, Grids &grids );
      static int sqrt( Grid &ogrid, Grid &grid );
      static int abs( Grid &ogrid, Grid &grid );
      static int inv( Grid &ogrid, Grid &grid );
      static int log( Grid &ogrid, Grid &grid );
      static int log10( Grid &ogrid, Grid &grid );
      static int exp( Grid &ogrid, Grid &grid );
      static int pow( Grid &ogrid, Grid &grida, Grid &gridb );
      static int adjustUV( Grid &ugrid, Grid &vgrid );
      static int locatePoint( Grid &ogrid, Grid &grid, const char *oper );
      static int coriolis( Grid &ogrid, Grid &grid, const char *oper );
      static int dx( Grid &ogrid, Grid &grid );
      static int dy( Grid &ogrid, Grid &grid );
      static int laplacian( Grid &ogrid, Grid &grid );
      static int converge( Grid &ogrid, Grid &ugrid, Grid &vgrid, Grid &zgrid );
      static int converge( Grid &ogrid, Grid &ugrid, Grid &vgrid );
      static int vorticity( Grid &ogrid, Grid &ugrid, Grid &vgrid );
      static int deformation1( Grid &ogrid, Grid &ugrid, Grid &vgrid );
      static int deformation2( Grid &ogrid, Grid &ugrid, Grid &vgrid );
      static int advection( Grid &ogrid, Grid &ugrid, Grid &vgrid, Grid &zgrid );
      static int windSpd( Grid &ogrid, Grid &ugrid, Grid &vgrid );
      static int windDir( Grid &ogrid, Grid &ugrid, Grid &vgrid, int flag );
      static int windU( Grid &ogrid, Grid &dgrid, Grid &sgrid, int flag );
      static int windV( Grid &ogrid, Grid &dgrid, Grid &sgrid, int flag );
      static int dewTemp( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int relHum( Grid &ogrid, Grid &tgrid, Grid &dgrid );
      static int specHum( Grid &ogrid, Grid &tgrid, Grid &dgrid );
      static int wetBulb( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int mixRatio( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int windChill( Grid &ogrid, const char *func, Grid &tgrid, 
	    Grid &sgrid );
      static int heatIndex( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int potTemp( Grid &ogrid, Grid &grid );
      static int virtTemp( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int virtPotTemp( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int equivPotTemp( Grid &ogrid, Grid &tgrid, Grid &rgrid );
      static int geosU( Grid &ogrid, Grid &hgrid );
      static int geosV( Grid &ogrid, Grid &hgrid );
      static int showalter( Grid &ogrid, Grid &t8grid, Grid &r8grid, Grid &t5grid );
      static int adjustDir( Grid &ugrid, Grid &vgrid, Domain &dom, int flag );

      enum {
	 UVGRID,
	 UVEW
      };
   };
}   
#endif
