#ifndef _WINC_GVAR
#define _WINC_GVAR

#include <WXP/Angle.h>
#include <WXP/Attitude.h>
#include <WXP/AttitudeAngle.h>
#include <WXP/DateVal.h>
#include <WXP/EarthPoint.h>
#include <WXP/EarthPoint2.h>
#include <WXP/Point2.h>
#include <WXP/SatAngle.h>
#include <WXP/SatPoint.h>

namespace WXP {
   class Gvar {
      int idntfr;      /*   2     IDNTFR = */
      int imcact;      /*   3     IMCACT = IMC active flag */
      float reflon;    /*   6    +REFLON = Reference longitude */
      float refdis;    /*   7    +REFDIS = Reference distance from nominal */
      float reflat;    /*   8    +REFLAT = Reference latitude */
      float refyaw;    /*   9    +REFYAW = Reference yaw */
      Attitude ref_att;/*  10    +RATROL = Reference attitude roll */
                       /*  11    +RATPTC = Reference attitude pitch */
                       /*  12    +RATYAW = Reference attitude yaw */
      double epoch;    /*  13-14  ETIME  = Epoch time */
      float edtime;    /*  15    +EDTIME = Delta from epoch time */
      Attitude im_mot_cor;/*  16    +IMCROL = Image motion compensation roll */
                       /*  17    +IMCPTC = Image motion compensation pitch */
                       /*  18    +IMCYAW = Image motion compensation yaw */
      float ldr[13];   /*  19-31 +LDR    = Longitude delta from ref parameters */
      float rddr[11];  /*  32-42 +RDDR   = Radial distance delta from ref params */
      float dgl[9];    /*  43-51 +DGL    = Geocentric latitude delta parameters */
      float doy[9];    /*  52-60 +DOY    = Orbit yaw delta parameters */
      float solinc;    /*  61     reserved */
      float exptim;    /*  62    +EXPTIM = Exponential start time from epoch */
      AttitudeAngle raawds;  /*  63-117 RAAWDS = Roll attitude angle words */
      AttitudeAngle paawds;  /* 130-184 PAAWDS = Pitch attitude angle words */
      AttitudeAngle yaawds;  /* 185-239 YAAWDS = Yaw attitude angle words */
      AttitudeAngle rmawds;  /* 258-312 RMAWDS = Roll misalignment angle words */
      AttitudeAngle pmawds;  /* 313-367 PMAWDS = Pitch misalignment angle words */
      double imgtim;   /* 368-369 IMGDATM = Image time value (YYDDD) */
      int imgsnd;      /* 370     IMGSND = Imager/sounder instrument flag */
      
      int imc;
      
      /*  ELCOMM include variables */
      double bt[3][3];       /* Instrument to ECEF coordinates transformation */
      double q3;             /* Used in function lpoint */
      Attitude inst_att;     /* Pitch,roll,yaw angles of instrument (rad) */
      float pma,rma;         /* Pitch,roll misalignments of instrument (rad) */
      /*  INSTCO include variables */
      int inc_max[2];        /* Number of increments per cycle */
      float elev_bnds[2];    /* Bounds in elevation (radians) */
      float scan_bnds[2];    /* Bounds in scan angle (radians) */
      float elev_inc[2];     /* Change in elevation angle per increment (rad) */
      float scan_inc[2];     /* Change in scan angle per increment (radians) */
      float elev_dln[2];     /* Elevation angle per detector line (radians) */
      float scan_pix[2];     /* Scan angle per pixel (radians) */
      /*  GVRCOM common variables */
      int itype;
      int instr;
      EarthPoint2 sat_sub;
      /*  SAVCOM common variables */
      Point2 xs;             /* Normalized S/C position in ECEF coordinates */
      double b[3][3];        /* Spacecraft to ECEF coordinates transformation */
      double dr;
      Angle phi;
      Angle psi;
      
      public:
      int initConstants( int nadnsc, int nadnsi, int nadewc, int nadewi);
      int initParams();
      int instMatrix( Attitude att, double a[3][3] , double at[3][3] );
      int getSubPoint( EarthPoint &ept );
      float getScanDelta();
      float getElevDelta();
      int tran( SatPoint &spt, SatAngle &sa );
      int tran( SatAngle &sa, SatPoint &spt );
      int tran( SatPoint &spt, EarthPoint &ept );
      int tran( EarthPoint &ept, SatPoint &spt );
      int tran( SatAngle &sa, EarthPoint &ept );
      int tran( EarthPoint &ept, SatAngle &sa );

      static double epochTime( DateVal dv );
      static double epochTime( unsigned int dmy, unsigned int smh );
      static int setAttitudeAngle( int *data, AttitudeAngle &param );
      static double adjustAttitude( AttitudeAngle &parms, double sol_ang, double exp_tim);
      
      const static double RADE_EQUA;
      const static double RADE_POLE;
      const static double RADE_MEAN;
      const static double SOLAR_YR;
      const static double SIDER_YR;
      const static double SOLSID;
      const static int REF_DATE;
      const static int REF_TIME;
      const static double PREC_VER_EQ;
      const static double OBLIQ_ECLIP;
      const static double NOMORB;
      const static double REQ;
      const static double RPL;
      const static double REQRPL2;
      const static double FER;
      const static double FER2;
      const static double REQRPL3;
      const static double REQRPL4;
      
      friend class AreaFile;
   };
}
#endif
   

