#ifndef _WINC_HASH
#define _WINC_HASH

namespace WXP {
   class Hash {
      int type;		  /* The type of hash */
      int size;           /* The vertical table size */
      int data_size;      /* The size in bytes of the data in table */

      struct HashEntry {
   	 char *key;          /* The key to the element in the table */
   	 char *data;         /* The data stored in the database */
   	 HashEntry *link;    /* A link to the next element at that hash address */
   	 HashEntry *next;    /* A link to the next element in the order
   				entered into the database */
      };

      HashEntry *cur;     /* Pointer to element in table based on order entered */
      HashEntry *head;    /* Pointer to head element based on order entered */
      HashEntry *last;    /* Pointer to last element based on order entered */
      int num;            /* Total number of entries in table */
      int numkey;         /* The number of keys used to search table */
      HashEntry **table[4];/* Pointer to tables based on keys */

      int initClass();
      int clearAll();
   
      public:
      Hash( int rtype, int rsize, int rdata_size, int rnumkey );
      Hash( int rsize, int rdata_size, int rnumkey );
      Hash( int rtype );
      Hash();
      ~Hash();
      int init();
      int set( int rtype, int rsize, int rdata_size, int rnumkey );
      int set( int rsize, int rdata_size, int rnumkey );
      int set( int rtype );
      int set();
      int key( const char *rkey );
      int enter( const char *data, ... );
      char *search( int keynum, const char *key );
      char *search( const char *key );
      int searchInt( int keynum, const char *rkey );
      int searchInt( const char *rkey );
      int searchBool( int keynum, const char *rkey );
      int searchBool( const char *rkey );
      float searchFloat( int keynum, const char *rkey );
      float searchFloat( const char *rkey );
      int first();
      char *next();
      char *nextKey();
      int clear();
      inline int getSize(){ return size; };
      inline int getDataSize(){ return data_size; };
      inline int getNumKey(){ return numkey; };
      inline int getNum(){ return num; };
      int print();
      int printData();
      int printHash();

      enum {
	 STRING,
	 BOOL,
	 INT,
	 FLOAT,
	 DATA
      };
   };
} 
#endif
