#ifndef _WINC_IMAGE
#define _WINC_IMAGE

#include <WXP/Date.h>
#include <WXP/DateVal.h>
#include <WXP/Domain.h>
#include <WXP/DomainVal.h>
#include <WXP/EarthPoint.h>
#include <WXP/FloatArray.h>
#include <WXP/GeomBox.h>
#include <WXP/GridPoint.h>
#include <WXP/ImageColor.h>
#include <WXP/Point.h>
#include <WXP/Rect.h>
#include <WXP/RGB.h>
#include <WXP/String.h>

namespace WXP {
   class Image {
      int source;               /* Source of image */
      int type;                 /* Type of image */
      int version;              /* Version of image */
      char datim[50];           /* Date and time information */
      Date date;
      char info[80];            /* Label for image information */
      int width;                /* Image type used in image */
      int height;               /* Image type used in image */
      int depth;                /* Image type used in image */
      float xres,yres;          /* Image resolution */
      float xoff,yoff;          /* Image offset */
      int bits_pixel;           /* Bits per pixel */
      int bytes_line;           /* Number of bytes per scan line */
      int byte_order;           /* Bytes order in data */
      int color_type;           /* Color type used in image */
      unsigned int red_mask;   /* Red mask for true color */
      unsigned int grn_mask;   /* Green mask for true color */
      unsigned int blu_mask;   /* Blue mask for true color */
      int num_colors;           /* Image type used in image */
      ImageColor *colors;       /* Color array */
      int trans_color;     /* Transparent color index */
      Domain domain;            /* The image domain */
      int index;
      bool pix_ave;
      int cutoff[7];
      int cutbase;
      int numcut;
      float *values;    	/* A pointer an array of pixel values*/
      unsigned char *data;      /* A pointer to the image */
   
      public:
      int initClass();
      int init();
      Image( );
      Image( const Image &image );
      ~Image( );
      int copy( Image &image );
      int copyInfo( Image &image );
      int copyData( Image &image );
      Image operator=(const Image &image);
      int set( int rwidth, int rheight, int rdepth );
      int set( Domain &rdomain, int rdepth );
      int set( DomainVal &rdv, int rdepth );
      int allocData();
      int clearData();
      bool validData();
      int allocColors( int num );
      /** Returns if image has colormap with it */
      inline int hasColors(){ return colors != NULL; };
      int setSource( int val );
      int setType( int val );
      int setDate( int secs );
      int setDate( DateVal &dv );
      int setDate( Date &d );
      int getDate( Date &rdate );
      Date getDate();
      int setDatim( const char *str );
      int setDatim( String &str );
      char *getDatim();
      int setInfo( const char *str );
      int setInfo( String &str );
      char *getInfo();
      int setDomain( DomainVal &val );
      int setDomain( Domain &dom );
      int getDomainProj();
      Domain getDomain();
      int getDomain( Domain &dom );
      DomainVal getDomainVal();
      inline float getPLat(){ return domain.getPLat(); };
      inline float getPLon(){ return domain.getPLon(); };
      inline int getWidth(){ return width; };
      inline int getHeight(){ return height; };
      inline int getDepth(){ return depth; };
      inline int getBytes(){ return bytes_line*height; };
      inline int getBytesLine(){ return bytes_line; };
      inline int getColorType(){ return color_type; };
      inline int getNumColors(){ return num_colors; };
      float getRed( int ind );
      float getGrn( int ind );
      float getBlu( int ind );
      int setWidth( int val );
      int setHeight( int val );
      int setDepth( int val );
      int setBitsPixel( int val );
      int setBytesLine( int val );
      int setBytesLine();
      int setColorType( int val );
      int setByteOrder( int val );
      int setRedMask( unsigned long );
      inline unsigned int getRedMask(){ return red_mask; };
      int setGrnMask( unsigned long );
      inline unsigned int getGrnMask(){ return grn_mask; };
      int setBluMask( unsigned long );
      inline unsigned int getBluMask(){ return blu_mask; };
      int setRed( int ind, float val );
      int setGrn( int ind, float val );
      int setBlu( int ind, float val );
      int setColor( int ind, float r, float g, float b );
      int setColor( int ind, RGB &rgb );
      int setRGB( int ind, RGB &rgb );
      int getRGB( int ind, RGB &rgb );
      int setTransColor( int clr );
      inline bool hasTransColor(){ return trans_color != -1; };
      inline int getTransColor(){ return trans_color; };
      int setColorVal( int ind, int val );
      int getColorVal( int ind );
      int setPixAve( bool val );
      inline int setCutBase( int val ){ cutbase = val; return 1; };
      int setCutoff( int ind, int val );
      int setCutoff( char *str );
      inline bool hasCutoff(){ return cutoff[0] != Const::MISS; };
      inline int getCutBase(){ return cutbase; };
      inline int getCutoff(int i){ return cutoff[i+1]; };
      inline int getNumCut(){ return numcut; };
      int print();
      int printInt();
      int printValues();
      int printColors();
      int printHist();
      int printData( EarthPoint &ept );
      int getPixel( int x, int y );
      int getVal( int x, int y );
      bool isPixelTrans( int x, int y );
      int getRGB( int x, int y, RGB &rgb );
      int getRow( int row, unsigned char *odata );
      inline const unsigned char *getData(){ return data; };
      int getPixel( float x, float y );
      int getPixel( GridPoint gpt );
      int getPixel( EarthPoint ept );
      int getPixel( Point pt );
      int allocValues();
      inline bool hasValues(){ return values != NULL; };
      int setValue( int ind, float val );
      int setValues( FloatArray &array );
      float getValue( int ind );
      int getIndex( float val );
      float getValue( int x, int y );
      float getValue( float x, float y );
      float getValue( Point &pt );
      float getValue( GridPoint &gpt );
      float getValue( EarthPoint &ept );
      int getVal( EarthPoint &ept );
      int setPixel( int x, int y, int val );
      int setPixel( int val );
      int setPixel( GridPoint gpt, int val );
      int setValue( int x, int y, float val );
      Rect getLimits();
      inline int getProj(){ return domain.getProj(); };
      int tran( EarthPoint ept, Point &pt );
      int tran( Point pt, EarthPoint &ept );
      int tran( GridPoint gpt, Point &pt );
      int tran( Point pt, GridPoint &gpt );
      int tran( EarthPoint ept, GridPoint &gpt );
      int tran( GridPoint gpt, EarthPoint &ept );
      float getDx();
   
      static int copyInfo( Image &image1, const Image &image2 );
      static int copyData( Image &image1, const Image &image2 );
      static int copy( Image &image1, const Image &image2 );
   
      friend class ImageMath;
      /*
         Image data requests
      */
      enum Query { ALL, INQ };
      enum Type { UNK, IMG, GINI, AREA };
      enum ByteOrder { LSB, MSB };
      enum ColorType { TRUECOL, INDEX, VALUE };
   };
} 
#endif
