#ifndef _WINC_LEV2FILE
#define _WINC_LEV2FILE

#include <WXP/Buffer.h>
#include <WXP/BZlib.h>
#include <WXP/Date.h>
#include <WXP/File.h>
#include <WXP/Lev2Data.h>
#include <WXP/Lev2Info.h>

namespace WXP {
   class Lev2File { 
      File file;
      bool opened;
      Date date;
      int type;
      int compress; // Compressed or Encypted
   
      // Bzip2 parameters
      Buffer in;
      Buffer out;
      BZlib bz;
      int err;

      int blk_off;
      int blk_next;
      int blk_size;
      int blk_num;
    
      // Product description
      char id[10];
      float lat,lon;
      int msg_type;
      int scan_type;
      int refl_ptr;
      int vel_ptr;
      int spect_ptr;
      int vol_ptr;
      int elev_ptr;
      int rad_ptr;
      int num_refl;
      int num_vel;

      float refl_size;
      int refl_bits;
      float refl_scl;
      float refl_off;

      float vel_size;
      int vel_bits;
      float vel_scl;
      float vel_off;
   
      float spect_size;
      int spect_bits;
      float spect_scl;
      float spect_off;
   
      int initClass();
      public:
      Lev2File();
      Lev2File( const char *filename, int rtype );
      ~Lev2File();
      int init();
      int open( const char *filename, int rtype );
      int close();
      bool isOpen();
      int readData();
      int readBytes( unsigned char *data, int dsize );
      int bseek( int byte );
      int boffset( int byte );
      int getByte();
      int getUByte();
      int getShort();
      int getLong();
      float getFloat();
      int setId( const char *rid );
      const char *getId(){ return id; };
      int setDataType( int type );
      int getNumData();
      int setCompress( int val );
      /** Returns whether data are compressed */
      inline int getCompress(){ return compress; };
      int getHeader( Lev2Info &info );
      int getBlock( Lev2Data &data );
      int nextBlock();
      float getData();
   
      bool hasRef();
      bool hasVel();
      bool hasSpect();

      /** File type */
      enum Type {
         RAW,   /**< Raw uncompressed data */
         COMP   /**< Compressed data */
      };

      /** Data type */
      enum DataType {
         REF,   /**< Reflectivity */
         VEL,   /**< Velocity */
         SPECT  /**< Spectrum width */
      };
   
   };
}
#endif
