#ifndef _WINC_LEV2IMAGE
#define _WINC_LEV2IMAGE

#include <WXP/Date.h>
#include <WXP/Domain.h>
#include <WXP/Filename.h>
#include <WXP/Grid.h>
#include <WXP/Image.h>
#include <WXP/Lev2Info.h>

namespace WXP {
   class Lev2Image { 
      int cradius;
      int ramp_cut;
      int ramp_len;
      float thres[200];
      int mix[200];
      int snow[200];
      int nthres;
      int clear_air;
      int interp;
      int type;
      int mode;
   
      Lev2Info info;
      Domain domain;
      Date date;
      int compress;
      int scan_num;
      float range;  // Valid range to use in mosaic
      int nbin;  // Number of scan bins in array
      int num;   // Number of values in scan
      float dist;  // Distance between each value in scan
      int valid;   // Whether read in data is valid
      float *data;
      int data_size;

      public:
      Lev2Image();
      Lev2Image( const char *str );
      ~Lev2Image();
      int init();
      int setParam( const char *str );
      int setFileType( int type );
      int setRamp( int cut, int len );
      int setThres( const char *str );
      inline int setClutterRad( int crad ){ cradius = crad; return 1; };
      inline int setCompress( int val ){ compress = val; return 1; };
      int setClearAirUse( int val );
      int getMode();
      int getIndex( float val );
      int readSite( Filename &filename );
      int readSite( Filename &filename, const char *id );
      int setup( Image &image );
      int addSite( Image &image );
      int addSite( Filename &filename, Image &image );
      int setImage( Filename &filename, Image &image );
      int applyMask(Image &image, Grid &mask);
      int print();
      int printSite();

   };
}
#endif
