#ifndef _WINC_LEV2PLOT
#define _WINC_LEV2PLOT

#include <WXP/Date.h>
#include <WXP/Domain.h>
#include <WXP/Drawing.h> 
#include <WXP/EarthPoint.h> 
#include <WXP/Filename.h>
#include <WXP/Listener.h>
#include <WXP/Plot.h>
#include <WXP/String.h>
#include <WXP/Timezone.h>

namespace WXP {
   class Lev2Plot : public Drawing, public Listener {
      char id[5];
      char datim[40];
      char title[40];
      char misc[40];
      int file_type;
      int plt_site;
      int plt_graph;
      float plt_dist[10];
      float plt_azimuth;
      String color_table;
      String color_fill;
      int range;
      int clutter_rad;
      int scan_num;
      int scan_type;
      bool map;
      int sync;
      Filename filename; 
      Timezone tz; 
   
      public:
      Lev2Plot();
      Lev2Plot( const char *str );
      int init();
      int setParam( const char *str );
      int setFile();
      int setInput( const char *type );
      int setId( const char *str );
      int setNameConv( const char *name );
      int setHour( const char *str );
      int setFilename();
      int setFilename( const char *file );
      int setFilename( Date &date );
      int setFilename( Date &date, const char *param );
      inline int setForeTime( const char *fore ){ return 1; };
      int getDate( Date &date );
      int getInitDate( Date &date );
      int getDateOffset();
      int getLoopType();
      int getNumFrames();
      int getDomain( EarthPoint ept, Domain &domain );
      int getDomain( Domain &domain );
      int setVariable( const char *variable );
      int setColorTable( const char *str );
      int setColorFill( const char *str );
      inline int setMap( bool val ){ map = val; return 1; };
      inline int getSync(){ return sync; };
      int draw( Plot &plot );
      void callback( const char *ev_str, const char *ev_data, const void *data );
      int print();

      enum Type { RAW, COMP };
   };
}
#endif
