#ifndef _WINC_MOSDATA
#define _WINC_MOSDATA

#include <WXP/Date.h>
#include <WXP/EarthPoint.h>
#include <WXP/String.h>

namespace WXP {
   class MosData {
      public:
      const static int NumData = 25;  /**< Maximum number of reports */
      private:
      char id[7];               /* Station identifier */
      float lat;                /* Latitude */
      float lon;                /* Longitude */
      float elev;               /* Elevation */
      Date date;                /* Initial time of data */
   
      int model;                /* The model used in the data */
      int num;                  /* The number of forecasts */
      int hour[NumData];        /* The hour offset */
      int t[NumData];           /* The temperature */
      int td[NumData];          /* The dewpoint */
      int wdir[NumData];        /* The wind direction */
      int wspd[NumData];        /* The wind speed */
      int pop6[NumData];        /* The 6 hour probability of precipitation */
      int pop12[NumData];       /* The 12 hour probability of precipitation */
      int pop24[NumData];       /* The 24 hour probability of precipitation */
      int pot6[NumData];        /* The 6 hour probability of thunderstorms */
      int pot12[NumData];       /* The 12 hour probability of thunderstorms */
      int pot24[NumData];       /* The 24 hour probability of thunderstorms */
      int post6[NumData];       /* The 6 hour prob of severe thunderstorms */
      int post12[NumData];      /* The 12 hour prob of severe thunderstorms */
      int pozp[NumData];        /* The prob of freezing precip */
      int posn[NumData];        /* The prob of frozen precip */
      char ptype[NumData];      /* The precipitation type */
      int tmax[NumData];        /* The max temperature */
      int tmin[NumData];        /* The min temperature */
      char cover[NumData];      /* The cloud cover */
      int ceil[NumData];        /* The cloud ceiling */
      int vis[NumData];         /* The visibility */
      char obvis[NumData];      /* The obscuration to visibility */
      int qpf6[NumData];        /* The 6 hour quantitative precipitation */
      int qpf12[NumData];       /* The 12 hour quantitative precipitation */
      int qpf24[NumData];       /* The 24 hour quantitative precipitation */
      int qsf6[NumData];        /* The 6 hour quantitative snow */
      int qsf12[NumData];       /* The 12 hour quantitative snow */
      int qsf24[NumData];       /* The 24 hour quantitative snow */

      int nmax;                 /* The normal max temperature */
      int nmin;                 /* The normal min temperature */
      int npop;                 /* The normal prob of precip */

      public:
      enum Model { NONE, NGM, AVN, GFS, ETA, NAM, MRF, GFSX, LFM, LAMP };
   
      MosData();
      int init();
      int setId( const char *rid );
      int setId( const char *rid, float rlat, float rlon );
      const char *getId();
      int getLoc( float &rlat, float &rlon );
      int getLoc( EarthPoint &ept );
      EarthPoint getLoc();
      /** Returns the latitude of the station */
      inline float getLat(){ return lat; };
      /** Returns the longitude of the station */
      inline float getLon(){ return lon; };
      int setElev( float relev );
      float getElev();
      int getSeconds();
   
      int setDate( Date &rdate );
      int getDate( Date &rdate );
      Date getDate();
      int setModel( int val );
      int getModel();
      int setNum( int val );
      int getNum();
      int setHour( int ind, int val );
      int getHour( int ind );
      int getInd( float hr );
      int setT( int ind, int val );
      int getT( int ind );
      int setTd( int ind, int val );
      int getTd( int ind );
      int setCover( int ind, char val );
      char getCover( int ind );
      int setCeiling( int ind, int val );
      int getCeiling( int ind );
      int setVis( int ind, int val );
      int getVis( int ind );
      int setObvis( int ind, char val );
      char getObvis( int ind );
      int setTMax( int ind, int val );
      int getTMax( int ind );
      int setTMin( int ind, int val );
      int getTMin( int ind );
      int setWDir( int ind, int val );
      int getWDir( int ind );
      int setWSpd( int ind, int val );
      int getWSpd( int ind );
      int setPop6( int ind, int val );
      int getPop6( int ind );
      int setPop12( int ind, int val );
      int getPop12( int ind );
      int setPop24( int ind, int val );
      int getPop24( int ind );
      int setPot6( int ind, int val );
      int getPot6( int ind );
      int setPot12( int ind, int val );
      int getPot12( int ind );
      int setPot24( int ind, int val );
      int getPot24( int ind );
      int setPost6( int ind, int val );
      int getPost6( int ind );
      int setPost12( int ind, int val );
      int getPost12( int ind );
      int setPType( int ind, char val );
      char getPType( int ind );
      int setQpf6( int ind, int val );
      int getQpf6( int ind );
      int setQpf12( int ind, int val );
      int getQpf12( int ind );
      int setQsf6( int ind, int val );
      int getQsf6( int ind );
      int setQsf12( int ind, int val );
      int getQsf12( int ind );
      float cldHght( int ind );
      float visibility( int ind );
      float quantPrec6( int ind );
      float quantPrec12( int ind );
      float quantPrec24( int ind );
      float snow6( int ind );
      float snow12( int ind );
      float snow24( int ind );
      int weather6( int ind, String &wx6 );
      int weather12( int ind, String &wx12 );

      /** Returns the normal maximum temperature */
      inline int getNMax(){ return nmax; };
      /** Returns the normal minimum temperature */
      inline int getNMin(){ return nmin; };
      /** Returns the normal probability of precipitation */
      inline int getNPop(){ return npop; };

      int print();
      int printTable();

      friend class MosFile;
      friend class MosDataTool;
   };
}   
#endif
