#ifndef _WINC_NIDSFILE
#define _WINC_NIDSFILE

#include <WXP/Buffer.h>
#include <WXP/BZlib.h>
#include <WXP/Date.h>
#include <WXP/DomainVal.h>
#include <WXP/File.h>
#include <WXP/NidsData.h>
#include <WXP/NidsInfo.h>
#include <WXP/NidsRadial.h>
#include <WXP/NidsRun.h>
#include <WXP/NidsText.h>
#include <WXP/NidsVector.h>
#include <WXP/NidsWind.h>
#include <WXP/Zlib.h>

namespace WXP {

   class NidsFile { 
      File file;
      bool opened;
      DomainVal dom;
      Date date;
      int file_type; // Compressed or Encypted
      int comp_test; // Test for compression
   
      Buffer in;
      Buffer buf;
      Zlib zs;
      BZlib bz;
    
      // Header parameters
      int code;
      int mess_date;
      int mess_len;
      int src;
      int mess_blks;
   
      // Product description
      float lat,lon,elev;
      int mode;        // Mode = clear air, precip
      int vol_scan;
      int vol_date;
      int vcp;
      int seq;
      int prod_date;
      int param[10];
      int ithres[16];  // Threshold values
      float thres[16];
      int nmaps;       // Offset information
      int off_symb;
      int off_graph;
      int off_tab;
   
      // Product symbology
      int prodsym_len;
      int prodsym_lyr;
   
      // Product symbology layer
      int prodsym_lyr_len;
   
      // Packet 
      int pk_code;
   
      // Radial parameters
      int rad, bin;
      int nrad, nbin;
      int rad0, bin0;
      float ang0, ang1;
   
      // Rastor parameters
      int row, col;
      int nrow, ncol;
      int row0, col0;
   
      // Generic packet parameters
      int len, num;
      int val;
      int bytes, nbytes;
      int pack;
   
      // Product parameter data
      float res;
      float dx,dy;
      int nx,ny;
      int scan_num;
      float scan_elev;
      float range;
      float max,nmax;
      int beg_date;
      int end_date;
      int num_graph;
   
      int setInfo( char *info );
      int setMisc( char *misc );

      public:
      NidsFile();
      NidsFile( const char *filename );
      ~NidsFile();
      int init();
      int open( const char *filename );
      int close();
      bool isOpen();
      int skipLine();
      int readBytes( unsigned char *data, int size );
      int dump( int num, int flag );
      int readShort( short &val );
      short readShort();
      int readUshort( unsigned short &val );
      int readLong( int &val );
      int readLong();
      int readUlong( unsigned int &val );
      float float16( int val );
      float float32( int val1, int val2 );
      int readHeader( NidsInfo &info );
      int messHeader();
      int prodDesc();
      int prodSymb();
      int prodSymbLayer();
      int gotoGraphic();
      int graphic();
      int graphicLayer();
      int readPacket();
   
      int readRastor();
      int readRadial( NidsRadial &radial );
      int readRun( NidsRun &data );
      int readVector( NidsVector &vect );
      int skipVector();
      int readText( NidsText &text );
      int skipText();
      int readWind( NidsWind &wind );
      int skipWind();
      int readData( NidsData &data );
   
      inline int getCode(){ return code; };
      bool isBRef();
      bool isBSW();
      bool isCRef();
      bool isVel();
      bool isSRVel();
      bool isTops();
      bool isEnhTops();
      bool isLRef();
      bool isVIL();
      bool isDigVIL();
      bool isVAD();
      bool isPrec();
      bool isDPrec();
      bool isDPrRate();
      bool isHydroClass();
      bool isCorrel();
      bool isDPA();
      bool isDHR();
      bool isDSP();
      bool isDRef();
      bool isDual();
      bool isPacketRadial();
      bool isPacketRastor();
      bool isPacketVector();
      bool isPacketWindbarb();
      bool isPacketText();
      bool isPacketDpa();
      int getPacketCode();
      int getNbin();
      DomainVal getDomainVal();
   
      static const int RADIAL = 0xAF1F;
      static const int RASTOR = 0xBA0F;

      enum Mode {
	 OM,
	 CLEARAIR,
	 PRECIP
      };
      enum Type {
	 REG,
	 ZCOMP,
	 ENC,
	 BCOMP
      };
   };
}
#endif

