#ifndef _WINC_POINTS
#define _WINC_POINTS

#include <WXP/Const.h>
#include <WXP/Point.h>

namespace WXP {
   class Points {                /* Coordinate data structure */
      int num;
      int max;
      int ind;
      float *x;     /**< X value */
      float *y;     /**< Y value */
   
      public:
      int init();
      int init( int size );
      Points();
      Points(int size);
      ~Points();
      Points( const Points &data );
      Points operator=( const Points &data );       
      int copy( const Points &data );
      int copy( const Points &data, int start, int rnum );
      /** Clears point array */
      inline int clear(){ num = 0; return 1; };
      int expand( int size );
      int add( float x, float y );
      int add( Point pt );
      /** Adds a point (no bounds check \param pt	Point to add */
      inline int add1( Point pt ){ x[num] = pt.x; y[num] = pt.y; num++; return 1; };
      int add( int ind );
      /** Adds an existing point (no bounds check \param ind	Index of point to add */
      inline int add1( int ind ){ x[num] = x[ind]; y[num] = y[ind]; num++; return 1; };
      int set( int ind, float rx, float ry );
      int set( int ind, Point &pt );
      int get( int ind, Point &pt );
      Point get( int ind );
      int remove( int ind );
      int insert( int ind, Point &pt );
      int insert( int ind, float x, float y );
      /** Returns X value \param ind	Index in array */
      inline float getX( int ind ){ 
	 return ind >= num || ind < 0 ? Const::MISS : x[ind]; };
      /** Returns Y value \param ind	Index in array */
      inline float getY( int ind ){ 
	 return ind >= num || ind < 0 ? Const::MISS : y[ind]; };
      /** Returns X value (no bounds check) \param ind	Index in array */
      inline float getX1( int ind ){ return x[ind]; };
      /** Returns Y value (no bounds check) \param ind	Index in array */
      inline float getY1( int ind ){ return y[ind]; };
      /** Return the number of points */
      inline int getNum() { return num; };
      int offset( int ind, float rx, float ry );
      int offset( float rx, float ry );
      int within( Point &pt );
      int getCenter( Point &pt );
      int getCentroid( Point &pt );
      int print();
   };
}
#endif
