#ifndef _WINC_RADMASK
#define _WINC_RADMASK

#include <WXP/Date.h>
#include <WXP/Domain.h>
#include <WXP/EarthPoint.h>
#include <WXP/Filename.h>
#include <WXP/Grid.h>

namespace WXP {
   class RadMask {
      char model[20];
      Date fdate;
      Domain domain;
      Grid gtsfc;
      Grid grsfc;
      Grid gt0;
      Grid gt60;
      Grid gt150;
      Grid gr150;
      int fhour;
      int hour;
      bool use_hdr;
      
      public:
      RadMask();
      ~RadMask();
      int init();
      int setModel( const char *mod );
      /** Sets the forecast hour used to read in grids */
      inline int setForeHour( int val ){ fhour = val; return 1; };
      /** Sets the forecast hour used to read in grids */
      inline int useHdrFile( bool val ){ use_hdr = val; return 1; };
      int getDate( Date &rdate );
      int setDomain( DomainVal &dv );
      int setDomain( Domain &dom );
      int getGrids( Filename &filename );
      int getGrids( Date &date );
      int getGrids( const char *file );
      int getGrids();
      /** Returns surface temperature for a location */
      inline float getTSfc( EarthPoint &ept ){ return gtsfc.getValue(ept); };
      /** Returns surface humidity for a location */
      inline float getRSfc( EarthPoint &ept ){ return grsfc.getValue(ept); };
      /** Returns 0mb AG temperature for a location */
      inline float getT0( EarthPoint &ept ){ return gt0.getValue(ept); };
      /** Returns 60mb AG temperature for a location */
      inline float getT60( EarthPoint &ept ){ return gt60.getValue(ept); };
      /** Returns 150mb AG temperature for a location */
      inline float getT150( EarthPoint &ept ){ return gt150.getValue(ept); };
      /** Returns 150mb AG humidity for a location */
      inline float getR150( EarthPoint &ept ){ return gr150.getValue(ept); };
      /** Returns surface temperature for a gridpoint */
      inline float getTSfc( int i, int j ){ return gtsfc.getValue(i,j); };
      /** Returns surface humidity for a gridpoint */
      inline float getRSfc( int i, int j ){ return grsfc.getValue(i,j); };
      /** Returns 0mb AG temperature for a gridpoint */
      inline float getT0( int i, int j ){ return gt0.getValue(i,j); };
      /** Returns 60mb AG temperature for a gridpoint */
      inline float getT60( int i, int j ){ return gt60.getValue(i,j); };
      /** Returns 150mb AG temperature for a gridpoint */
      inline float getT150( int i, int j ){ return gt150.getValue(i,j); };
      /** Returns 150mb AG humidity for a gridpoint */
      inline float getR150( int i, int j ){ return gr150.getValue(i,j); };
      int getWinterFlag( float tsfc, float t60, float t150 );
      int getWinterFlag( int i, int j );
      int getWinterFlag( EarthPoint &ept );
      int getWinter( Grid &mask_grid );
      int getSiteFilter( EarthPoint &ept );
      int print();
   };
}   
#endif
