#ifndef _WINC_RADPLOT
#define _WINC_RADPLOT

#include <WXP/Date.h>
#include <WXP/DatumPlot.h>
#include <WXP/Domain.h>
#include <WXP/Drawing.h>
#include <WXP/Filename.h>
#include <WXP/Grid.h>
#include <WXP/Image.h>
#include <WXP/ImagePlot.h>
#include <WXP/Lev2Plot.h>
#include <WXP/Listener.h>
#include <WXP/MdrPlot.h>
#include <WXP/NidsPlot.h>
#include <WXP/RcmPlot.h>
#include <WXP/Plot.h>
#include <WXP/String.h>
#include <WXP/Timezone.h>

namespace WXP {
   class RadPlot : public Drawing, public Listener {
      int type;
      Filename filename;
      String color_table;
      String color_fill;
      ImagePlot img;
      NidsPlot nids;
      Lev2Plot lev2;
      MdrPlot mdr;
      RcmPlot rcm;
      int sync;
   
      public:
      RadPlot();
      RadPlot( const char *str );
      int init();
      int setParam( const char *str );
      int setPath( const char *path );
      int setFile();
      int setInput( const char *rtype );
      int getType( const char *rtype );
      int setNameConv( const char *name );
      int setHour( const char *str );
      int setFilename();
      int setFilename( const char *name );
      int setFilename( Date &date );
      int setFilename( Date &date, const char *param );
      inline int setForeTime( const char *fore ){ return 1; };
      int setColorTable( const char *str );
      int setColor( const char *str );
      int setColorFill( const char *str );
      int setVariable( const char *str );
      int setMap( bool val );
      int getDate( Date &date );
      int getInitDate( Date &date );
      int getDateOffset();
      int getLoopType();
      int getNumFrames();
      int getDomain( Domain &domain );
      inline int getSync(){ return sync; };
      int draw( Plot &plot, Image &image ); 
      int draw( Plot &plot ); 
      void callback( const char *ev_str, const char *ev_data, const void *data );
      int print();

      enum Type {
	 UNK,
	 MDR,
	 MDRSITE,
	 RCM,
	 RCMSITE,
	 IMG,
	 NIDS,
	 LEV2,
	 NOWRAD,
	 KAVRAD
      };
   };
}
#endif
