#ifndef _WINC_RAWFILE
#define _WINC_RAWFILE

#include <WXP/Data.h>
#include <WXP/Date.h>
#include <WXP/Datum.h>
#include <WXP/File.h>
#include <WXP/RawField.h>
#include <WXP/String.h>

namespace WXP {
   class RawFile {
      static const int MAXFIELD = 75;
      static const int MAXCHARS = 400;
      int type;
      int ver;
      int access;
      long pos;
      int num;             /* The seq number within the file */
      int ind;             /* The seq number for each station */
      int cur_field;       /* Current field number */
      int cur_pos;         /* Current position on line */
      RawField field[MAXFIELD];
      int num_field;       /* Number of fields */
      int field_off;       /* Offset of data from ID, location */
      char line[MAXCHARS];
      int length;
      char ident[20];
      float x,y;
      File file;
      Date date;
      char datim[50];      /* Date and time information */
      char info[50];       /* Parameter information */
      char ofmt[20];	// Output format
      bool opened;
   
      public:
      enum Type { UNK, WXP };
   
      RawFile();
      RawFile( const char *filename );
      RawFile( const char *filename, int access, int type );
      ~RawFile();
      int initClass();
      int init();
      int open( const char *filename, int access, int type );
      int open( const char *filename, int access );
      int open( const char *filename );
      int rewind();
      int close();
      inline const char *getDatim(){ return datim; };
      inline int getDate( Date &rdate ){ rdate = date; return 1; };
      inline const char *getInfo(){ return info; };
      const char *getInfo(int ind);
      int read();
      int read( Datum &data, int fnum );
      int read( Datum &data );
      int read( Data &data );
      int read( const char *filename, Data &data );
      int getData( const char *fld, Datum &data );
      int decodeString( int fnum, const char *str, Datum &data );
      int getIdent( String &id );
      int getField( const char *str );

      int setFormat( const char *str );
      int write( Data &data );
      int write( const char *filename, Data &data );
      int print();

      static int checkType( const char *filename );
   
      static const int ALL = -2;
      static const int KEY = -1;
   };
}
#endif
