#ifndef _WINC_SFCCDFFILE
#define _WINC_SFCCDFFILE

#include <WXP/NetCdfFile.h>
#include <WXP/Date.h>
#include <WXP/SfcData.h>

namespace WXP {
   class SfcCdfFile {
      int type;
      int ver;
      int access;
      long pos;
      int cnt;
      int num;
      NetCdfFile cdf;
      Date date;
      bool opened;
      /* variable ids */
      int  id_id;             /* Station ID id */
      int  time_id;           /* Obervation time id */
      int  lat_id;            /* Sttion latitude id */
      int  lon_id;            /* Station longitude id */
      int  elev_id;           /* Station elevation id */
      int  t_id;              /* Station temperature id */
      int  td_id;             /* Station dewpoint id */
      int  psl_id;            /* Sea level pressure id */
      int  altim_id;          /* Altimeter setting id */
      int  spd_id;            /* Wind speed id */
      int  dir_id;            /* Wind direction id */
      int  zcl_id;            /* Cloud base id */
      int  cc_id;             /* Cloud coverage id */
      int  vis_id;            /* Visibility id */
      int  region_id;         /* Region id */
      int  wx_id;             /* Station weather id */
      int  cld_id;            /* Cloud type id */
      int  ptend_t_id;        /* Pressure tendency type id */
      int  ptend_id;          /* Pressure tendency id */
      int  precip_id;         /* Precipitation id */
      int  r_precip_id;       /* Precipitation ref time id */
      int  snow_id;           /* Snow cover id */
      int  tmax_id;           /* Max temperature id */
      int  tmin6_id;          /* Min temperature id */
      int  tmax6_id;          /* Max temperature id */
      int  tmin_id;           /* Min temperature id */
      int  sun_id;            /* Sunshine id */
      int  remark_id;         /* Remark id */
      int  gust_id;           /* Wind gust id */
      int  sst_id;            /* SST id */
      int  wav_per_id;        /* Wave period id */
      int  wav_hgt_id;        /* Wave height id */
      int  intdata_id;        /* Station integer data id */
      int  intname_id;        /* Integer data names id */
      int  intunit_id;        /* Integer data units id */
      int  fltdata_id;        /* Station floating point data id */
      int  fltname_id;        /* Floating point data names id */
      int  fltunit_id;        /* Floating point data units id */
      long remark_len;        /* Length of remark section */
      long num_station;       /* Number of stations in netCDF file (current
					length of unlimited dimension) */
      float missing_f;        /* Missing float value - netCDF global attr */
      long missing_i;         /* Missing int value - netCDF global attr */
      char missing_c;         /* Missing char value - netCDF global attr */
   
      public:
      SfcCdfFile( );
      SfcCdfFile( const char *filename );
      SfcCdfFile( const char *filename, int access );
      ~SfcCdfFile( );
      bool isOpen();
      int open( const char *filename, int access );
      int rewind( );
      int close( );
      int setDate( Date &rdate );
      int getDate( Date &rdate );
      int read( SfcData &data );
      int write( SfcData &data );
   
      static int checkType( const char *filename );
   };
}   
#endif
