#ifndef _WINC_SFCDATA
#define _WINC_SFCDATA

#include <stdlib.h> 

#include <WXP/CloudLayer.h>
#include <WXP/Date.h>
#include <WXP/StrLib.h>
#include <WXP/String.h>

namespace WXP {
   class SfcData {
      public:
      static const int comment_len = 100;
      private:
      char id[11];              /* Station identifier */
      char name[25];            /* Long name for station */
      char area[11];            /* Regional identifier */
      int type;                 /* Report type (e.g. METAR, SA, SYNOP) */
      int stype;                /* Report subtype (e.g. SPECIAL, AUTO) */
      long wmo;                 /* WMO station number */
      float lat;                /* Station latitude */
      float lon;                /* Station longitude */
      float elev;               /* Station elevation */
      int prior;                /* Station plotting priority */
      Date date;                /* Observation time */
      int flag;                 /* Data flag */

      float t;                  /* Temperature in C */
      float td;                 /* Dewpoint in C */
      float dir;                /* Wind direction in Deg */
      float spd;                /* Wind speed in knt */
      float gust;               /* Wind gust in knt */
      float slp;                /* Sea level pressure in mb */
      float alt;                /* Altimeter setting in inHg */
      float vis;                /* Visibility in miles */
      CloudLayer cloud[5];      /* Cloud layers */
      int num_cld;              /* Number of cloud layers */
      char weather[21];         /* Type of weather */
      int ptend_type;           /* Type of pressure tendency */
      float ptend;              /* Pressure tendency */
      float prec3;              /* 3 hour precipitation in mm */
      float prec6;              /* 6 hour precipitation in mm */
      float prec12;             /* 12 hour precipitation in mm */
      float prec24;             /* 24 hour precipitation in mm */
      float prec;               /* XX hour precipitation in mm */
      int prec_per;             /* Period of time prec is valid */
      int cld_low;              /* Percent of low cloud cover */
      char cld_type[3];         /* Low, medium and high level cloud types */
      float max_t;              /* Maximum temperature in C */
      float min_t;              /* Minimum temperature in C */
      float max6_t;             /* 6 hour Maximum temperature in C */
      float min6_t;             /* 6 hour Minimum temperature in C */
      float snow_cov;           /* Snow cover information in cm */
      float solar;              /* Total minutes of sunshine */
      float sst;                /* Sea surface temperature in C */
      float wav_per;            /* Sea wave period */
      float wav_hgt;            /* Sea wave height in m */
      char comment[comment_len];/* The comment field */
   
      public:
      SfcData();
      int init( );
      inline int setId( const char *str ){
      	 StrLib::copy( id, 10, str ); return 1; };
      inline const char *getId(){ return id; };

      inline int setArea( const char *str ){
      	 StrLib::copy( area, 10, str ); return 1; };
      inline const char *getArea(){ return area; };

      inline int setName( const char *str ){
      	 StrLib::copy( name, 10, str ); return 1; };
      inline const char *getName(){ return name; };

      inline int setWmo( const char *str ){ wmo = atol( str ); return 1; };
      inline int getWmo(){ return wmo; };

      inline int setLoc( float rlat, float rlon ){
      	 lat = rlat; lon = rlon; return 1; };

      inline float getLat(){ return lat; }
      inline float getLon(){ return lon; }

      inline int setElev( float el ){ elev = el; return 1; }
      inline float getElev(){ return elev; }

      inline int setDate( Date rdate ){ date = rdate; return 1; }
      int getDate( Date &rdate );
      inline Date getDate(){ return date; }
      int getTime();
      int getHour();
      int getSeconds();

      inline int setType( int rtype ){ type = rtype; return 1; }
      inline int getType(){ return type; }

      inline int setT( float rt ){ t = rt; return 1; }
      inline float getT(){ return t; }

      inline int setTd( float rtd ){ td = rtd; return 1; }
      inline float getTd(){ return td; }

      inline int setDir( float rdir ){ dir = rdir; return 1; }
      inline float getDir(){ return dir; }

      inline int setSpd( float rspd ){ spd = rspd; return 1; }
      inline float getSpd(){ return spd; }

      inline int setGust( float rgust ){ gust = rgust; return 1; }
      inline float getGust(){ return gust; }

      inline int setAlt( float ralt ){ alt = ralt; return 1; }
      inline float getAlt(){ return alt; }

      inline int setSlp( float rslp ){ slp = rslp; return 1; }
      inline float getSlp(){ return slp; }

      inline int setVis( float rvis ){ vis = rvis; return 1; }
      inline float getVis(){ return vis; }

      inline int setWeather( const char *wx ){ 
	 StrLib::copy( weather, 21, wx ); return 1; }
      inline const char *getWeather(){ return weather; }
      int weatherText( String &str );

      inline int setNumCld( int num ){ num_cld = num; return 1; }
      inline int getNumCld(){ return num_cld; }

      int setCldHeight( int ind, float height );
      float getCldHeight( int ind );
      float getCldHeight();
      int setCldCover( int ind, char cover );
      char getCldCover( int ind );
      char getCldCover();

      inline int setPtendType( int type ){ ptend_type = type; return 1; }
      inline int getPtendType(){ return ptend_type; }

      inline int setPtend( float rptend ){ ptend = rptend; return 1; }
      inline float getPtend(){ return ptend; }

      inline int setPrec3( float val ){ prec3 = val; return 1; }
      inline float getPrec3(){ return prec3; }

      inline int setPrec6( float val ){ prec6 = val; return 1; }
      inline float getPrec6(){ return prec6; }

      inline int setPrec12( float val ){ prec12 = val; return 1; }
      inline float getPrec12(){ return prec12; }

      inline int setPrec24( float val ){ prec24 = val; return 1; }
      inline float getPrec24(){ return prec24; }

      inline int setPrec( float val ){ prec = val; return 1; }
      inline float getPrec(){ return prec; }

      inline int setPrecPer( int per ){ prec_per = per; return 1; }
      inline int getPrecPer(){ return prec_per; }

      inline int setCldLow( int low ){ cld_low = low; return 1; }
      inline int getCldLow(){ return cld_low; }

      int setCldType( int ind, char type );
      char getCldType( int ind );

      inline int setMaxT( float t ){ max_t = t; return 1; }
      inline float getMaxT(){ return max_t; }
      
      inline int setMinT( float t ){ min_t = t; return 1; }
      inline float getMinT(){ return min_t; }
      
      inline int setMax6T( float t ){ max6_t = t; return 1; }
      inline float getMax6T(){ return max6_t; }
      
      inline int setMin6T( float t ){ min6_t = t; return 1; }
      inline float getMin6T(){ return min6_t; }
      
      inline int setSnowCov( float snow ){ snow_cov = snow; return 1; }
      inline float getSnowCov(){ return snow_cov; }
      
      inline int setSolar( float solar ){ solar = solar; return 1; }
      inline float getSolar(){ return solar; }
      
      inline int setSst( float sst ){ sst = sst; return 1; }
      inline float getSst(){ return sst; }
      
      inline int setWavPer( float wav_per ){ wav_per = wav_per; return 1; }
      inline float getWavPer(){ return wav_per; }
      
      inline int setWavHgt( float wav_hgt ){ wav_hgt = wav_hgt; return 1; }
      inline float getWavHgt(){ return wav_hgt; }

      int setComment( const char *str );
      int addComment( const char *str );
      int addComment( const char *str, int num );
      const char *getComment();
      int setFlag( int val );
      int orFlag( int val );
      int getFlag();
      int print();
      int printLine();
      int outString( String &str );
      int update( SfcData &rep, int lev );
      inline int update( SfcData &rep ){ return update( rep, 0xFFFF ); };
      int validate();
   
      static int compare( SfcData &rep1, SfcData &rep2 );
      static int printDiff( int diff );
   
      friend class SfcDataTool;
      friend class SfcDecode;
      friend class MetarTool;
      friend class SynopTool;
      friend class SaoTool;
      friend class SfcFile;
      friend class SfcWxpFile;
      friend class SfcCdfFile;
      friend class SfcXmlFile;
      /*
         Define data locations
      */
      enum Locate { USA, CANADA, MEXICO, OTHER };

      enum StatType { MANNED, AMOS, ASOS, AWOS };
      
      enum RepType { 
	 UNK, 
	 METAR, 
	 SPECI, 
	 SA, 
	 SP, 
	 SYNOP, 
	 SHIP, 
	 BUOY, 
	 DRIBU, 
	 CMAN, 
	 MISC 
      };
      // Define special flags
      static const int  RMK   = 0x1;
      static const int  TGRP  = 0x2;

      static const int  SPECIAL = 1;
      static const int  CORRECT = 2;
      static const int  AUTO    = 4;

      static const int DF_TYPE = 1;
      static const int DF_TIME = 1 << 1;
      static const int DF_TEMP = 1 << 2;
      static const int DF_PRES = 1 << 3;
      static const int DF_WIND = 1 << 4;
      static const int DF_WX   = 1 << 5;
      static const int DF_CLD  = 1 << 6;
      static const int DF_VIS  = 1 << 7;
      static const int DF_PTND = 1 << 8;
      static const int DF_PREC = 1 << 9;
      static const int DF_EXTT = 1 << 10;
      static const int DF_SNOW = 1 << 11;
      static const int DF_SOL  = 1 << 12;
      static const int DF_SEA  = 1 << 13;
      static const int DF_CTYP = 1 << 14;
      static const int DF_COM  = 1 << 15;
   };
}
#endif
