#ifndef _WINC_THERMPLOT
#define _WINC_THERMPLOT

#include <WXP/DomainVal.h>
#include <WXP/Drawing.h>
#include <WXP/Listener.h>
#include <WXP/Plot.h>
#include <WXP/Rect.h>
#include <WXP/String.h>

namespace WXP {
   class ThermPlot : public Drawing {
      int type;
      String color_grid;
      String color_label;
      String mixrat;
      float tmin, tmax, tinc;
      float pmin, pmax, pinc;

      public:
      ThermPlot();
      ThermPlot( const char *str );
      int init();
      int setType( int rtype );
      int setType( const char *str );
      int getType();
      int getDomain( Domain &domain );
      int setParam( const char *str );
      int setFile();
      int setInput( const char *str );
      int setNameConv( const char *name );
      int setFilename();
      int setFilename( const char *name );
      int setFilename( Date &date );
      int setFilename( Date &date, const char *param );
      /** Sets forecast time (ignored) */
      inline int setForeTime( const char *fore ){ return 1; };
      int getDate( Date &date );
      int getInitDate( Date &date );
      int getDateOffset();
      int getLoopType();
      int getNumFrames();
      /** Returns whether object is time sync (unused) */
      inline int getSync(){ return 0; };

      int setGridColor( const char *str );
      int setLabelColor( const char *str );
      int setVertAxis( float rmin, float rmax, float rinc );
      int setHorAxis( float rmin, float rmax, float rinc );

      int draw( Plot &plot );
      int print();

      static DomainVal getDomain( int type );
      static int getType( const char *str );

      enum Type { SKEWT, STUVE, EMA, TEPH, RTEPH, HODO };
   };
}
#endif
