#ifndef _WINC_UPARAWINDATA
#define _WINC_UPARAWINDATA

#include <WXP/Date.h>
#include <WXP/EarthPoint.h>
#include <WXP/StrLib.h>
#include <WXP/UpaLevel.h>

namespace WXP {
   class UpaRawinData {
      public:
      static const int max_man = 25;
      static const int max_sig = 250;
      static const int max_wnd = 150;
      private:
      char id[11];              /* Station identifier */
      char area[11];            /* Regional identifier */
      char wmo[6];              /* WMO station number */
      int type;                 /* Observation type */
      Date date;                /* Full date */
      float lat;                /* Station latitude */
      float lon;                /* Station longitude */
      float elev;               /* Station elevation */
   
      UpaLevel man[max_man];     /* Mandatory level information */
      int num_man;               /* Number of mandatory levels */
      int sfc;                  /* Index of surface level */
      int maxwnd;               /* Index of max wind level */
      int trop;                 /* Index of tropopause level */
   
      UpaLevel sig[max_sig];     /* Significant level information */
      int num_sig;               /* Number of significant levels */
   
      UpaLevel wnd[max_wnd];     /* Wind level information */
      int num_wnd;               /* Number of wind levels */
   
      public:
      UpaRawinData();
      int init();
      int setType( int rtype );
      inline int getType(){ return type; };
      int setDate( Date rdate );
      inline Date getDate(){ return date; };
      int getTime();
      int setId( const char *rid );
      int setId( const char *rid, const char*rwmo, float rlat, float rlon );
      inline const char *getId(){ return id; };
      int setArea( const char *rarea );
      inline const char *getArea(){ return area; };
      inline int setWmo( const char *rwmo ){ StrLib::copy( wmo, 5, rwmo ); return 1; };
      inline const char *getWmo(){ return wmo; };
      inline int setLat( float rlat ){ lat = rlat; return 1; };
      inline int setLon( float rlon ){ lon = rlon; return 1; };
      int getLoc( float &rlat, float &rlon );
      inline float getLat(){ return lat; };
      inline float getLon(){ return lon; };
      EarthPoint getLoc();
      int setElev( float relev );
      inline float getElev(){ return elev; };
   
      int setSfc( int rsfc );
      int getSfc();
      int setTrop( int rtrop );
      int getTrop();
      int setMaxWnd( int rmaxwnd );
      int getMaxWnd();
   
      inline int getNumMan(){ return num_man; };
      int setMan( int ind, UpaLevel rlevel );
      int addMan( UpaLevel rlevel );
      float getManPr( int i );
      UpaLevel getMan( int i );
   
      inline int getNumSig(){ return num_sig; };
      int setSig( int ind, UpaLevel rlevel );
      int addSig( UpaLevel rlevel );
      float getSigPr( int i );
      UpaLevel getSig( int i );
   
      inline int getNumWnd(){ return num_wnd; };
      int setWnd( int ind, UpaLevel rlevel );
      int addWnd( UpaLevel rlevel );
      float getWndHt( int i );
      UpaLevel getWnd( int i );
   
      int sort();
      int print();

      friend class UpaTool;
   };
}   
#endif
