#ifndef _WINC_VARLIST
#define _WINC_VARLIST

#include <WXP/GridSpec.h>
#include <WXP/String.h>
#include <WXP/VarSpec.h>
#include <WXP/VarFile.h>
#include <WXP/VarFileData.h>

namespace WXP {
   class VarList {
      struct VarListItem {
	 int layer; // Layer of nesting
	 int dindex;  // Data index
	 VarSpec data;
      };

      VarListItem *list;
      int num;
      int max;
      int ind;
      int plot;
      char title[80];
      String varfilename;
      char delim;
      char nest[10];
      int n;

      bool checkDelim( const char *data, int i );
      int pushDelim( char d );
      char popDelim();
      char getLastDelim();
      int printDelim();
      int cleanData( char *data );

      public:
      VarList();
      ~VarList();
      int init();
      int resize( int rmax );
      int setFile( const char *file );
      int searchFile( const char *var, String &data );
      int decode( const char *str );
      int decode( VarFileData &data );
      int rewind();
      int next();
      bool done();
      inline int getNum(){ return num; };
      int get( int i, VarSpec &vspec );
      int get( int i, GridSpec &gspec );
      int setPlot(int i, int rplot);
      int getType();
      int getType(int i);
      int getLayer();
      int getLayer(int i);
      int setDataIndex(int i, int val);
      int getDataIndex();
      int getDataIndex(int i);
      int getString( int i, String &str );
      bool isGroup();
      bool isGroup(int i);
      bool isParam();
      bool isParam(int i);
      bool isData();
      bool isData(int i);
      bool isVect();
      bool isVect(int i);
      bool isFunction();
      bool isFunction(int i);
      bool isPlot();
      bool isPlot(int i);
      bool isPanel();
      bool isPanel(int i);
      bool isMap();
      bool isMap(int i);
      bool isContour();
      bool isContour(int i);
      bool isFillContour(int i);
      bool isVector();
      bool isVector(int i);
      inline const char *getTitle(){ return title; };
      const char *getName();
      const char *getName(int i);
      const char *getUnits();
      const char *getUnits(int i);
      const char *getFormat();
      const char *getFormat(int i);
      int print();
      int print(int ind);

      static int process( const char *str, VarList &vlist );
   };
}
#endif
