#ifndef _WINC_VARIABLE
#define _WINC_VARIABLE

#include <WXP/String.h>

namespace WXP {
   class Variable {
      int type;
      int ind;
      float val1;
      float val2;
      char abbr[40];
      char name[40];
      char units[20];

      public:
      static const int max_abbr = 40;
      static const int max_name = 40;
      static const int max_units = 20;

      Variable();
      Variable( const char *ab );
      Variable( const char *ab, const char *unit );
      int init();
      int set( const char *ab );
      int set( const char *ab, const char *unit );
      int setType( int t );
      /** Gets the variable type */
      inline int getType(){ return type; };
      int setInd( int t );
      /** Gets the variable index */
      inline int getInd(){ return ind; };
      /** Sets the first value */
      inline int setVal1( float val ){ val1 = val; return 1; };
      /** Gets the first value */
      inline float getVal1(){ return val1; };
      /** Sets the second value */
      inline int setVal2( float val ){ val2 = val; return 1; };
      /** Gets the second value */
      inline float getVal2(){ return val2; };
      int setName( const char *str );
      /** Gets the variable long name */
      inline const char *getName(){ return name; };
      int setAbbr( const char *str );
      /** Gets the variable abbreviation */
      inline const char *getAbbr(){ return abbr; };
      int setUnits( const char *str );
      /** Gets the variable units */
      inline const char *getUnits(){ return units; };
      int toLabel( String &str );
      int toIndCode();
      int toAbbrCode( String &str );
      int toString( String &str );
      int decode( const char *str );
      int print();

      enum Type {
	 REG,
	 ACCUM,
	 MEAN,
	 MAX,
	 MIN,
	 PROB_LT,
	 PROB_GT,
	 PROB_LTH,
	 PROB_GTL,
	 PROB_BET,
	 ENS_MEMBER,
	 ENS_MEAN,
	 ENS_STDEV,
	 ENS_PROB_LT,
	 ENS_PROB_GT,
	 ENS_PROB_BET,
      };
   };
}
#endif
