#ifndef _WINC_VECTPLOT
#define _WINC_VECTPLOT

#include <WXP/ColorFill.h>
#include <WXP/Grid.h>
#include <WXP/Plot.h>
#include <WXP/String.h>

namespace WXP {
   class VectPlot {
      int type;
      int uvgrid;
      int skipx, skipy;
      float intrvl;
      float base;
      float speed;
      int density;
      float scale;
      float arrow_scale;
      float dom_scale;
      float min_cut;
      float max_cut;
      float max;
      String color_table;
      String color_data;
      String color_fill;
      String color_label;
      ColorFill fill;
      int bar;
      int *num;   // Used for streamlines
      int numsize;

      public:
      VectPlot();
      VectPlot( const char *param );
      int init();
      int setParam( const char *param );
      int setColorTable( const char *str );
      int setColorFill( const char *str );
      int setColor( const char *str );
      int setSkip( int x, int y );
      int setSkip( int val );
      int setInterval( float val );
      int setBase( float val );
      int setSpeed( float val );
      int setDensity( int val );
      int setScale( float val );
      int setArrowScale( float val );
      /** Returns the plot type */
      inline int getType(){ return type; };
      int setType( const char *str );
      /** Set the plot type \see Type */
      inline int setType( int rtype ){ type = rtype; return 1; };
      /** Returns the maximum wind of the current plot */
      inline float getMax(){ return max; };
      int drawLabels( Plot &plot, Grid &grid );
      int draw( Plot &plot, Grid &ugrid, Grid &vgrid );
      int drawStreamline( Plot &plot, Grid &ugrid, Grid &vgrid, 
      	    int i, int j, float length );
      int drawBar( Plot &plot, const char *locate );
      int drawVect( Plot &plot, const char *locate );

      /** Vector plot type */
      enum Type { 
	 VECTOR,  /**< Wind vectors */
	 BARB,    /**< Wind barbs */
	 STREAM   /**< Streamlines */
      };
   };
}
#endif
