#ifndef _WINC_WXP
#define _WINC_WXP

#include <WXP/Const.h>
#include <WXP/Convert.h>
#include <WXP/Resrc.h>

#undef NOFILE
#ifdef MACOSX
typedef int socklen_t;
#endif

namespace WXP {
   class Wxp : public Const, public Convert {
      static int error;
      static int message_mask;
      static int init_time;
      static int lic;
      static int lic_gif;
      static int lic_prodman;
      static int lic_nldn;
      static char *datapath;
      static char progname[20];
   
      static Resrc resrc;

      public:
   
      enum MessLevel { 
	 NONE,
	 PRINT,
	 ERROR,
	 WARN,
	 MESS,
	 OUT1,
	 OUT2,
	 OUT3,
	 OUT4,
	 OUT5,
	 OUT6,
	 OUT7,
	 OUT8,
	 DEBUG1,
	 DEBUG2,
	 DEBUG3,
	 DEBUG4,
	 DEBUG5,
	 DEBUG6,
	 DEBUG7,
	 DEBUG8 
      };
   
      /*
         error return values
      */
      enum Error {   /**< Exit error values */
          NOERR,     /**< No error */
          NORUN,     /**< Unable to run program or invalid license */
          MISC,      /**< Miscellaneous error */
          NOMEMORY,  /**< Not enough memory */
          NOGRAPH,   /**< Unable to open graphics */
          NOINIT,    /**< Cannot initialize program parameters */
          NOFILE,    /**< Data file not found */
          NODBASE,   /**< Database file not found */
          NOWRITE,   /**< Unable to write to output file */
          NOINPUT,   /**< Missing input data */
          NODATA,    /**< No data found */
          BADPARAM   /**< Bad parameter specified */
      };
   
      static bool isDebug();
      static bool isDebug(int level);
      static inline int setError( int val ){ error = val; return 1; };
      static inline bool getError(){ return error; };
      static int setMessageLevel( int val );
      static int setMessageLevel( const char *str );
      static inline int getMessageLevel(){ return message_mask; };
      static int setProgramName( const char *str );
      static const char *getProgramName();
      static int setDatabasePath( const char *str );
      static const char *getDatabasePath();
      static bool validLicense();
      static bool validLicense( const char *type );
      static int pause();
      static int sleep( float secs );
      static bool checkMessage(int level);
      static int outMessage( const char *mess, ... );
      static int print( const char *mess );
      static int outMessage( int level, const char *mess, ... );
      static int outWarning( const char *mess, ... );
      static int outError( const char *mess, ... );
      static int outDebug( const char *mess, ... );
      static int outDebug( int level, const char *mess, ... );
      static double getTime();
      static int getVirtMem();
      static int exit( Error val );
      static const char *getVersion();
      static const char *getLicenseVersion();
      static const char *getComputerName();

      static inline int setInitTime( int val ){
	 init_time = val; return 1;
      }

      static inline int getInitTime(){
	 return init_time;
      }

      static inline const char *getResrc( const char *name ){
      	 return resrc.get( name );
      }
      static inline bool getResrcBool( const char *name ){
      	 return resrc.getBool( name );
      }
      static inline const char *getResrc( const char *name, const char *def ){
      	 return resrc.get( name, def );
      }
      static inline float getResrc( const char *name, float val ){
      	 return resrc.get( name, val );
      }
      static inline int getResrc( const char *name, int val ){
      	 return resrc.get( name, val );
      }
      static inline int addResrc( const char *name, const char *data, int type ){
	 return resrc.add( name, data, type ); 
      };
      static inline int putResrc( const char *name, const char *data ){
	 return resrc.put( name, data ); 
      };
      static inline int setResrc( const char *name, const char *data ){
	 return resrc.set( name, data ); 
      };
      static inline int appendResrc( const char *name, const char *data ){
	 return resrc.append( name, data ); 
      };
      static inline int printAllResrc(){
      	 return resrc.printAll();
      }
      static inline const char *nextResrc(){
      	 return resrc.getNext();
      }
      static inline int rewindResrc(){
      	 return resrc.rewind();
      }
      static inline int getResrcType( const char *name ){
      	 return resrc.getType( name );
      }

      friend class ResrcDB;
      friend class Prog;
   };

}
#endif
